@@ -41,12 +41,10 @@
 # -------------------------------------------------------------------------
 #' @export
 new_epiweek <- function(x = integer()) {
-    if (!is.integer(x)) {
-        if (is.vector(x, "double")) {
-            x <- as.integer(floor(x))
-        } else {
-            stop("`x` must be integer.")
-        }
+    if (is.vector(x, "double")) {
+        x <- as.integer(floor(x))
+    } else if (!is.integer(x)) {
+        stop("`x` must be integer.")
     }
     .new_epiweek(x)
 }
@@ -98,21 +96,17 @@ new_epiweek <- function(x = integer()) {
 epiweek <- function(year = integer(), week = integer()) {
 
     # check year is integerish
-    if (!is.integer(year)) {
-        if (is.vector(year, "double")) {
-            year <- as.integer(floor(year))
-        } else {
-            stop("`year` must be integer.")
-        }
+    if (is.vector(year, "double")) {
+        year <- as.integer(floor(year))
+    } else if (!is.integer(year)) {
+        stop("`year` must be integer.")
     }
 
     # check week is integerish
-    if (!is.integer(week)) {
-        if (is.vector(week, "double")) {
-            week <- as.integer(floor(week))
-        } else {
-            stop("`week` must be integer.")
-        }
+    if (is.vector(week, "double")) {
+        week <- as.integer(floor(week))
+    } else if (!is.integer(week)) {
+        stop("`week` must be integer.")
     }
 
     # check compatible lengths
@@ -239,16 +233,16 @@ as_epiweek.character <- function(
             stop("If specified, `format` must be of length 1.")
 
         if (format == "yearweek") {
-            years <- sub("^([0-9]{4}).*","\\1", x, perl=TRUE)
+            years <- sub("^([0-9]{4}).*", "\\1", x, perl = TRUE)
             years <- suppressWarnings(as.integer(years))
-            weeks <- sub(".*-[wW]([0-9]{1,2}$)","\\1", x, perl=TRUE)
+            weeks <- sub(".*-[wW]([0-9]{1,2}$)", "\\1", x, perl = TRUE)
             weeks <- suppressWarnings(as.integer(weeks))
             out <- epiweek(year = years, week = weeks)
             return(out)
         }
     }
 
-    out <- as.Date(x, format = format, tryFormats = tryFormats,...)
+    out <- as.Date(x, format = format, tryFormats = tryFormats, ...)
     as_epiweek.Date(out)
 }
 
@@ -355,15 +349,18 @@ as.double.grates_yearweek <- function(x, ...) {
 # -------------------------------------------------------------------------
 #' @export
 as.Date.grates_epiweek <- function(x, ...) {
-    .Date(as.double(unclass(x)) * 7L + 3L)
+    .Date(as.double(unclass(x)) * 7 + 3)
 }
 
 # -------------------------------------------------------------------------
 #' @export
 as.POSIXct.grates_epiweek <- function(x, tz = "UTC", ...) {
     if (tz != "UTC")
-        stop("<grates_epiweek> objects can only be converted to UTC. If other timezones are required, first convert to <Date> and then proceed as desired.")
-    x <- as.double(unclass(x)) * 7 + 3L
+        stop(
+            "<grates_epiweek> objects can only be converted to UTC. ",
+            "If other timezones are required, first convert to <Date> and then proceed as desired."
+        )
+    x <- as.double(unclass(x)) * 7 + 3
     .POSIXct(x * 86400, tz = "UTC")
 }
 
@@ -371,8 +368,11 @@ as.POSIXct.grates_epiweek <- function(x, tz = "UTC", ...) {
 #' @export
 as.POSIXlt.grates_epiweek <- function(x, tz = "UTC", ...) {
     if (tz != "UTC")
-        stop("<grates_epiweek> objects can only be converted to UTC. If other timezones are required, first convert to <Date> and then proceed as desired.")
-    x <- as.double(unclass(x)) * 7L + 3L
+        stop(
+            "<grates_epiweek> objects can only be converted to UTC. ",
+            "If other timezones are required, first convert to <Date> and then proceed as desired."
+        )
+    x <- as.double(unclass(x)) * 7 + 3
     as.POSIXlt(x * 86400, tz = "UTC", origin = .POSIXct(0, tz = "UTC"))
 }
 
@@ -444,9 +444,8 @@ Ops.grates_epiweek <- function(e1, e2) {
     if (op %in% c("==", "!=", "<", ">", "<=", ">=")) {
         if (inherits(e2, "grates_epiweek")) {
             return(NextMethod())
-        } else {
-            stop("Can only compare <grates_epiweek> objects with <grates_epiweek> objects.")
         }
+        stop("Can only compare <grates_epiweek> objects with <grates_epiweek> objects.")
     }
 
     switch(
@@ -460,9 +459,8 @@ Ops.grates_epiweek <- function(e1, e2) {
                 return(.new_epiweek(unclass(e1) + as.integer(e2)))
             } else if (inherits(e2, "grates_epiweek") && (.is_whole(e1))) {
                 return(.new_epiweek(unclass(e2) + as.integer(e1)))
-            } else {
-                stop("Can only add integers to <grates_epiweek> objects.")
             }
+            stop("Can only add integers to <grates_epiweek> objects.")
         },
         "-" = {
             if (missing(e2)) {
@@ -471,16 +469,14 @@ Ops.grates_epiweek <- function(e1, e2) {
                 if (inherits(e1, "grates_epiweek")) {
                     weekdiff <- (unclass(e1) - unclass(e2))
                     return(as.difftime(weekdiff, units = "weeks"))
-                } else {
-                    stop("Can only subtract from a <grates_epiweek> object, not vice-versa.")
                 }
+                stop("Can only subtract from a <grates_epiweek> object, not vice-versa.")
             } else if (inherits(e1, "grates_epiweek") && is.integer(e2)) {
-                .new_epiweek(unclass(e1) - e2)
+                return(.new_epiweek(unclass(e1) - e2))
             } else if (inherits(e1, "grates_epiweek") && .is_whole(e2)) {
-                .new_epiweek(unclass(e1) - as.integer(e2))
-            } else {
-                stop("Can only subtract whole numbers and other <grates_epiweek> objects from <grates_epiweek> objects.")
+                return(.new_epiweek(unclass(e1) - as.integer(e2)))
             }
+            stop("Can only subtract whole numbers and other <grates_epiweek> objects from <grates_epiweek> objects.")
         },
         stopf("%s is not compatible with <grates_epiweek> objects.", op)
     )
@@ -494,7 +490,7 @@ Ops.grates_epiweek <- function(e1, e2) {
 # ------------------------------------------------------------------------- #
 
 .new_epiweek <- function(x) {
-    structure(x, class = c("grates_epiweek"))
+    structure(x, class = "grates_epiweek")
 }
 
 .epiweek <- function(year, week) {
